@@ -57,6 +57,7 @@ type Builder struct {
 	buildName        string
 	linkElf          string
 	injectedSettings map[string]string
+	modifiedExtRepos []string
 }
 
 func NewBuilder(
@@ -149,6 +150,10 @@ func (b *Builder) addPackage(rpkg *resolve.ResolvePackage) (
 	return bpkg, nil
 }
 
+func (b *Builder) GetAutogeneratedLinkerIncludeDir() (string, error) {
+	return b.targetBuilder.BspPkg().GetAutogeneratedLinkerIncludePath()
+}
+
 func pkgTypeConflictErr(p1 *BuildPackage, p2 *BuildPackage) error {
 	return util.FmtNewtError("Two %s packages in build: %s, %s",
 		pkg.PackageTypeNames[p1.rpkg.Lpkg.Type()],
@@ -469,6 +474,11 @@ func (b *Builder) link(elfName string, linkerScripts []string,
 	}
 
 	c.LinkerScripts = linkerScripts
+	c.AutogeneratedLinkerIncludeDir, err = b.GetAutogeneratedLinkerIncludeDir()
+	if err != nil {
+		return err
+	}
+
 	err = c.CompileElf(elfName, trimmedANames, keepSymbols, b.linkElf)
 	if err != nil {
 		return err
@@ -635,12 +645,40 @@ func buildWorker(
 	}
 }
 
+func (b *Builder) appendAppCflags(bpkgs []*BuildPackage) error {
+	for _, bpkg := range bpkgs {
+		settings := b.cfg.AllSettingsForLpkg(bpkg.rpkg.Lpkg)
+		globalAppCflags, err := bpkg.rpkg.Lpkg.PkgY.Get("app.cflags", settings)
+		if err != nil {
+			return err
+		}
+		for _, f := range globalAppCflags {
+			if itfVals, ok := f.Value.([]interface{}); ok {
+				for _, itfVal := range itfVals {
+					if strVal, ok := itfVal.(string); ok {
+						b.compilerInfo.Cflags = append(b.compilerInfo.Cflags, strVal)
+					}
+				}
+			}
+		}
+	}
+
+	return nil
+}
+
 func (b *Builder) Build() error {
+	var err error
+
 	b.CleanArtifacts()
 
 	// Build the packages alphabetically to ensure a consistent order.
 	bpkgs := b.sortedBuildPackages()
 
+	err = b.appendAppCflags(bpkgs)
+	if err != nil {
+		return err
+	}
+
 	// Calculate the list of jobs.  Each record represents a single file that
 	// needs to be compiled.
 	entries := []toolchain.CompilerJob{}
@@ -652,6 +690,8 @@ func (b *Builder) Build() error {
 		}
 		entries = append(entries, subEntries...)
 
+		b.modifiedExtRepos = append(b.modifiedExtRepos, bpkg.getModifiedReposNames()...)
+
 		if len(subEntries) > 0 {
 			bpkgCompilerMap[bpkg] = subEntries[0].Compiler
 		}
@@ -675,7 +715,6 @@ func (b *Builder) Build() error {
 		go buildWorker(i, jobs, stop, errors)
 	}
 
-	var err error
 	for i := 0; i < newtutil.NewtNumJobs; i++ {
 		subErr := <-errors
 		if err == nil && subErr != nil {
@@ -893,3 +932,24 @@ func (b *Builder) CleanArtifacts() {
 		os.Remove(p)
 	}
 }
+
+func Contains(elements []string, val string) bool {
+	for _, s := range elements {
+		if val == s {
+			return true
+		}
+	}
+	return false
+}
+
+func (b *Builder) AppendModifiedRepos(modifiedRepos []string) {
+	for _, repo := range modifiedRepos {
+		if !Contains(b.modifiedExtRepos, repo) {
+			b.modifiedExtRepos = append(b.modifiedExtRepos, repo)
+		}
+	}
+}
+
+func (b *Builder) GetModifiedRepos() []string {
+	return b.modifiedExtRepos
+}
