@@ -241,6 +241,10 @@ func (inst *Installer) shouldUpgradeRepo(
 		return true, nil
 	}
 
+	if r.IsUpgradedFromProjectYml() {
+		return false, nil
+	}
+
 	if !r.VersionsEqual(*curVer, destVer) {
 		return true, nil
 	}
@@ -590,6 +594,9 @@ func (inst *Installer) Upgrade(candidates []*repo.Repo, force bool,
 		if err := r.Upgrade(destVer); err != nil {
 			return err
 		}
+		if r.IsFromProjectYml() {
+			r.SetIsUpgradedFromProjectYml()
+		}
 		util.StatusMessage(util.VERBOSITY_DEFAULT,
 			"%s successfully upgraded to version %s\n",
 			r.Name(), destVer.String())
