@@ -24,6 +24,7 @@ import (
 	"fmt"
 	"io"
 	"io/ioutil"
+	"mynewt.apache.org/newt/newt/cfgv"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -80,6 +81,8 @@ const SYSCFG_TASK_PRIO_MAX = 0xef
 
 var cfgRefRe = regexp.MustCompile("MYNEWT_VAL\\((\\w+)\\)")
 var cfgChoiceValRe = regexp.MustCompile("^[A-Za-z0-9_]+$")
+var cfgPkgRepoName = regexp.MustCompile("^@([A-Za-z0-9-_]+)/")
+var cfgPkgIllegalChar = regexp.MustCompile("[^A-Za-z0-9_]")
 
 type CfgPoint struct {
 	Value  string
@@ -180,16 +183,16 @@ func NewCfg() Cfg {
 	}
 }
 
-func SettingValues(settings map[string]CfgEntry) map[string]string {
-	values := make(map[string]string, len(settings))
-	for k, v := range settings {
-		values[k] = v.Value
+func SettingValues(entries map[string]CfgEntry) *cfgv.Settings {
+	settings := cfgv.NewSettingsPrealloc(len(entries))
+	for k, v := range entries {
+		settings.Set(k, v.Value)
 	}
 
-	return values
+	return settings
 }
 
-func (cfg *Cfg) SettingValues() map[string]string {
+func (cfg *Cfg) SettingValues() *cfgv.Settings {
 	return SettingValues(cfg.Settings)
 }
 
@@ -263,34 +266,29 @@ func (cfg *Cfg) ResolveValueRefs() {
 //
 // Else (no injected settings), returns the base settings unmodified.
 func (cfg *Cfg) settingsForLpkg(lpkg *pkg.LocalPackage,
-	baseSettings map[string]string) map[string]string {
-
-	var settings map[string]string
+	baseSettings *cfgv.Settings) *cfgv.Settings {
 
 	injected := lpkg.InjectedSettings()
-	if len(injected) == 0 {
+	if injected.Count() == 0 {
 		return baseSettings
 	}
 
-	settings = make(map[string]string, len(baseSettings))
-	for k, v := range baseSettings {
-		settings[k] = v
-	}
+	settings := cfgv.NewSettings(baseSettings)
 
-	for k, v := range lpkg.InjectedSettings() {
-		_, ok := settings[k]
+	for k, v := range lpkg.InjectedSettings().ToMap() {
+		ok := settings.Exists(k)
 		if ok {
 			log.Warnf("Attempt to override syscfg setting %s with "+
 				"injected feature from package %s", k, lpkg.FullName())
 		} else {
-			settings[k] = v
+			settings.Set(k, v)
 		}
 	}
 
 	return settings
 }
 
-func (cfg *Cfg) AllSettingsForLpkg(lpkg *pkg.LocalPackage) map[string]string {
+func (cfg *Cfg) AllSettingsForLpkg(lpkg *pkg.LocalPackage) *cfgv.Settings {
 	return cfg.settingsForLpkg(lpkg, cfg.SettingValues())
 }
 
@@ -590,7 +588,7 @@ func (cfg *Cfg) addRedefine(settingName string,
 }
 
 func (cfg *Cfg) readDefsOnce(lpkg *pkg.LocalPackage,
-	settings map[string]string) error {
+	settings *cfgv.Settings) error {
 	yc := lpkg.SyscfgY
 
 	lsettings := cfg.settingsForLpkg(lpkg, settings)
@@ -683,7 +681,7 @@ func (cfg *Cfg) addOrphan(settingName string, value string,
 }
 
 func (cfg *Cfg) readRestrictions(lpkg *pkg.LocalPackage,
-	settings map[string]string) error {
+	settings *cfgv.Settings) error {
 
 	yc := lpkg.SyscfgY
 	lsettings := cfg.settingsForLpkg(lpkg, settings)
@@ -704,7 +702,7 @@ func (cfg *Cfg) readRestrictions(lpkg *pkg.LocalPackage,
 }
 
 func (cfg *Cfg) readValsOnce(lpkg *pkg.LocalPackage,
-	settings map[string]string) error {
+	settings *cfgv.Settings) error {
 	yc := lpkg.SyscfgY
 
 	lsettings := cfg.settingsForLpkg(lpkg, settings)
@@ -1222,7 +1220,7 @@ func categorizePkgs(
 }
 
 func (cfg *Cfg) readDefsForPkgType(lpkgs []*pkg.LocalPackage,
-	settings map[string]string) error {
+	settings *cfgv.Settings) error {
 
 	for _, lpkg := range lpkgs {
 		if err := cfg.readDefsOnce(lpkg, settings); err != nil {
@@ -1232,7 +1230,7 @@ func (cfg *Cfg) readDefsForPkgType(lpkgs []*pkg.LocalPackage,
 	return nil
 }
 func (cfg *Cfg) readValsForPkgType(lpkgs []*pkg.LocalPackage,
-	settings map[string]string) error {
+	settings *cfgv.Settings) error {
 
 	for _, lpkg := range lpkgs {
 		if err := cfg.readValsOnce(lpkg, settings); err != nil {
@@ -1261,11 +1259,11 @@ func (cfg *Cfg) DetectErrors(flashMap flashmap.FlashMap) {
 }
 
 func Read(lpkgs []*pkg.LocalPackage, apis []string,
-	injectedSettings map[string]string, settings map[string]string,
+	injectedSettings *cfgv.Settings, settings *cfgv.Settings,
 	flashMap flashmap.FlashMap) (Cfg, error) {
 
 	cfg := NewCfg()
-	for k, v := range injectedSettings {
+	for k, v := range injectedSettings.ToMap() {
 		cfg.Settings[k] = CfgEntry{
 			Name:        k,
 			Description: "Injected setting",
@@ -1276,7 +1274,7 @@ func Read(lpkgs []*pkg.LocalPackage, apis []string,
 			}},
 		}
 
-		settings[k] = v
+		settings.Set(k, v)
 	}
 
 	// Read system configuration files.  In case of conflicting settings, the
@@ -1580,7 +1578,40 @@ func writeReposInfo(w io.Writer) {
 	}
 }
 
-func write(cfg Cfg, w io.Writer) {
+func sanitizePkgName(name string) string {
+	name = cfgPkgRepoName.ReplaceAllString(name, "${1}__")
+	name = cfgPkgIllegalChar.ReplaceAllLiteralString(name, "_")
+
+	return name
+}
+
+func writePackages(lpkgs []*pkg.LocalPackage, w io.Writer) {
+	pkgs := []string{}
+	for _, lpkg := range lpkgs {
+		pkgs = append(pkgs, sanitizePkgName(lpkg.NameWithRepo()))
+	}
+
+	sort.Strings(pkgs)
+
+	fmt.Fprintf(w, "/*** Included packages */\n")
+	for _, name := range pkgs {
+		fmt.Fprintf(w, "#define MYNEWT_PKG_%s 1\n", name)
+	}
+}
+
+func writeApis(apis []string, w io.Writer) {
+	for i, api := range apis {
+		apis[i] = cfgPkgIllegalChar.ReplaceAllLiteralString(api, "_")
+	}
+	sort.Strings(apis)
+
+	fmt.Fprintf(w, "/*** Included APIs */\n")
+	for _, name := range apis {
+		fmt.Fprintf(w, "#define MYNEWT_API_%s 1\n", name)
+	}
+}
+
+func write(cfg Cfg, lpkgs []*pkg.LocalPackage, apis []string, w io.Writer) {
 	fmt.Fprintf(w, newtutil.GeneratedPreamble())
 
 	fmt.Fprintf(w, "#ifndef H_MYNEWT_SYSCFG_\n")
@@ -1597,10 +1628,16 @@ func write(cfg Cfg, w io.Writer) {
 	writeSettings(cfg, w)
 	fmt.Fprintf(w, "\n")
 
+	writePackages(lpkgs, w)
+	fmt.Fprintf(w, "\n")
+
+	writeApis(apis, w)
+	fmt.Fprintf(w, "\n")
+
 	fmt.Fprintf(w, "#endif\n")
 }
 
-func EnsureWritten(cfg Cfg, includeDir string) error {
+func EnsureWritten(cfg Cfg, includeDir string, lpkgs []*pkg.LocalPackage, apis []string) error {
 	// XXX: Detect these problems at error text generation time.
 	if err := calcPriorities(cfg, CFG_SETTING_TYPE_TASK_PRIO,
 		SYSCFG_TASK_PRIO_MAX, false); err != nil {
@@ -1609,7 +1646,7 @@ func EnsureWritten(cfg Cfg, includeDir string) error {
 	}
 
 	buf := bytes.Buffer{}
-	write(cfg, &buf)
+	write(cfg, lpkgs, apis, &buf)
 
 	path := includeDir + "/" + HEADER_PATH
 
