@@ -38,13 +38,19 @@ import (
 	"time"
 
 	log "github.com/sirupsen/logrus"
+
+	"github.com/otiai10/copy"
 )
 
 var Verbosity int
 var PrintShellCmds bool
+var InjectSyscfg string
 var ExecuteShell bool
 var EscapeShellCmds bool
+var ShallowCloneDepth int
 var logFile *os.File
+var SkipNewtCompat bool
+var SkipSyscfgRepoHash bool
 
 func ParseEqualsPair(v string) (string, string, error) {
 	s := strings.Split(v, "=")
@@ -367,7 +373,10 @@ func ShellCommandLimitDbgOutput(
 	if ExecuteShell && (runtime.GOOS == "linux" || runtime.GOOS == "darwin") {
 		cmd := strings.Join(cmdStrs, " ")
 		name = "/bin/sh"
-		args = []string{"-c", strings.Replace(cmd, "\"", "\\\"", -1)}
+		cmd = strings.Replace(cmd, "\"", "\\\"", -1)
+		cmd = strings.Replace(cmd, "<", "\\<", -1)
+		cmd = strings.Replace(cmd, ">", "\\>", -1)
+		args = []string{"-c", cmd}
 	} else {
 		if strings.HasSuffix(cmdStrs[0], ".sh") {
 			var newt_sh = os.Getenv("NEWT_SH")
@@ -536,39 +545,18 @@ func CopyFile(srcFile string, dstFile string) error {
 }
 
 func CopyDir(srcDirStr, dstDirStr string) error {
-	srcDir, err := os.Open(srcDirStr)
+	opt := copy.Options{
+		OnSymlink: func(src string) copy.SymlinkAction {
+			return copy.Shallow
+		},
+	}
+
+	err := copy.Copy(srcDirStr, dstDirStr, opt)
+
 	if err != nil {
 		return ChildNewtError(err)
 	}
 
-	info, err := srcDir.Stat()
-	if err != nil {
-		return ChildNewtError(err)
-	}
-
-	if err := os.MkdirAll(dstDirStr, info.Mode()); err != nil {
-		return ChildNewtError(err)
-	}
-
-	infos, err := srcDir.Readdir(-1)
-	if err != nil {
-		return ChildNewtError(err)
-	}
-
-	for _, info := range infos {
-		src := srcDirStr + "/" + info.Name()
-		dst := dstDirStr + "/" + info.Name()
-		if info.IsDir() {
-			if err := CopyDir(src, dst); err != nil {
-				return err
-			}
-		} else {
-			if err := CopyFile(src, dst); err != nil {
-				return err
-			}
-		}
-	}
-
 	return nil
 }
 
